==> osso-gwconnect_0.81.4.tar.gz: osso-gwconnect-0.81.4/src/btsdp-dbus.h <==
/**
  @file btsdp-dbus.h

  @author Johan Hedberg <johan.hedberg@nokia.com>

  Copyright (C) 2004 Nokia. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#ifndef _BTSDP_DBUS_H_
#define _BTSDP_DBUS_H_

#include <dbus/dbus.h>

typedef void (*sdp_reply_func_t)(DBusMessage    *message,
                                 DBusConnection *connection,
                                 GError         *error,
                                 GSList         *services);
typedef struct {
    sdp_reply_func_t  func;
    DBusMessage      *message;
    DBusConnection   *connection;
    GSList           *services;
} sdp_cb_data_t;

/** Bind functions to corresponding D-Bus messages
 * @param connection D-Bus connection
 */
void init_dbus_handlers(DBusConnection *connection);

/** Free memory allocated to handlers
 * @param connection D-Bus connection
 */
void destroy_dbus_handlers(DBusConnection *connection);

#endif /* _BTSDP_DBUS_H_ */

==> osso-gwconnect_1.0.12.tar.gz: osso-gwconnect-1.0.12/src/btsdp-dbus.h <==
/**
  @file btsdp-dbus.h

  @author Johan Hedberg <johan.hedberg@nokia.com>

  Copyright (C) 2006 Nokia Corporation. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/
#ifndef _BTSDP_DBUS_H_
#define _BTSDP_DBUS_H_

#include <dbus/dbus.h>

typedef void (*sdp_reply_func_t)(DBusMessage    *message,
                                 DBusConnection *connection,
                                 GError         *error,
                                 GSList         *services);
typedef struct {
    sdp_reply_func_t  func;
    DBusMessage      *message;
    DBusConnection   *connection;
    GSList           *services;
} sdp_cb_data_t;

/** Bind functions to corresponding D-Bus messages
 * @param connection D-Bus connection
 */
void init_dbus_handlers(DBusConnection *connection);

/** Free memory allocated to handlers
 * @param connection D-Bus connection
 */
void destroy_dbus_handlers(DBusConnection *connection);

#endif /* _BTSDP_DBUS_H_ */
